camelot.camelot.types

Package camelot :: Package camelot :: Package types |
[hide private]
[frames] | no frames]

# Package types

source code

Classes | [hide private]
| VirtualAddress Sqlalchemy type to store virtual addresses : eg, phone number, e-mail address, ...
| Code Sqlalchemy column type to store codes
| IPAddress
| RichText Sqlalchemy column type to store rich text
| StoredImage Class linking a PIL image and the location and filename where the image is stored
| Image Sqlalchemy column type to store images

Variables | [hide private]
| logger = `logging.getLogger('camelot.types')`